==> jc-1.4.0.tar.gz: javax/security/auth/x500/X500PrivateCredential.h <==
// public final class javax.security.auth.x500.X500PrivateCredential

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bb4192ff81632bf javax_security_auth_x500_X500PrivateCredential

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_x500_X500PrivateCredential_H_
#define _JC_javax_security_auth_x500_X500PrivateCredential_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_cert_X509Certificate$object;

// Typedefs
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs	_jc_javax_security_auth_x500_X500PrivateCredential$sub_refs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs	_jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$refs	_jc_javax_security_auth_x500_X500PrivateCredential$refs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$nonrefs	_jc_javax_security_auth_x500_X500PrivateCredential$nonrefs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$object	_jc_javax_security_auth_x500_X500PrivateCredential$object;

typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vmethods	_jc_javax_security_auth_x500_X500PrivateCredential$vmethods;
typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vtable	_jc_javax_security_auth_x500_X500PrivateCredential$vtable;
typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vtype	_jc_javax_security_auth_x500_X500PrivateCredential$vtype;

// Constructors
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$_init$3f4e0e94281bd3b5(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *);
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$_init$8ff1e9a1af422b73(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$destroy$883b1ab213ac7851(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getAlias$b9393ba4dce5808c(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
extern struct _jc_java_security_cert_X509Certificate$object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getCertificate$8ff48fa1edd22360(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
extern struct _jc_object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getPrivateKey$e03d9b3f371a9d56(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
extern jboolean _jc_javax_security_auth_x500_X500PrivateCredential$method$isDestroyed$78592fea7eb2b64b(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$destroy$883b1ab213ac7851;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getAlias$b9393ba4dce5808c;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getCertificate$8ff48fa1edd22360;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getPrivateKey$e03d9b3f371a9d56;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$isDestroyed$78592fea7eb2b64b;

// Virtual methods structure
struct _jc_javax_security_auth_x500_X500PrivateCredential$vmethods {
	void	(*destroy$883b1ab213ac7851)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
	struct _jc_java_lang_String$object	*(*getAlias$b9393ba4dce5808c)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
	struct _jc_java_security_cert_X509Certificate$object	*(*getCertificate$8ff48fa1edd22360)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
	struct _jc_object	*(*getPrivateKey$e03d9b3f371a9d56)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
	jboolean	(*isDestroyed$78592fea7eb2b64b)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *);
};

// Vtable
struct _jc_javax_security_auth_x500_X500PrivateCredential$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_x500_X500PrivateCredential$vmethods	javax_security_auth_x500_X500PrivateCredential;
};

// Vtype
struct _jc_javax_security_auth_x500_X500PrivateCredential$vtype {
	_jc_type			type;
	_jc_javax_security_auth_x500_X500PrivateCredential$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs {
	struct _jc_object	*key;
	struct _jc_java_security_cert_X509Certificate$object	*certificate;
	struct _jc_java_lang_String$object	*alias;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_x500_X500PrivateCredential$refs {
    _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs	javax_security_auth_x500_X500PrivateCredential;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_x500_X500PrivateCredential$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs	javax_security_auth_x500_X500PrivateCredential;
};

// Object instance structure
struct _jc_javax_security_auth_x500_X500PrivateCredential$object {
	_jc_javax_security_auth_x500_X500PrivateCredential$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_x500_X500PrivateCredential$vtype	*vtype;
	_jc_javax_security_auth_x500_X500PrivateCredential$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_x500_X500PrivateCredential$vtype _jc_javax_security_auth_x500_X500PrivateCredential$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_x500_X500PrivateCredential, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_x500_X500PrivateCredential$class_object;

#endif	/* _JC_javax_security_auth_x500_X500PrivateCredential_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/x500/X500PrivateCredential.h <==
// public final class javax.security.auth.x500.X500PrivateCredential

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bb4192ff81632bf javax_security_auth_x500_X500PrivateCredential

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_x500_X500PrivateCredential_H_
#define _JC_javax_security_auth_x500_X500PrivateCredential_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_cert_X509Certificate$object;

// Typedefs
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs	_jc_javax_security_auth_x500_X500PrivateCredential$sub_refs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs	_jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$refs	_jc_javax_security_auth_x500_X500PrivateCredential$refs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$nonrefs	_jc_javax_security_auth_x500_X500PrivateCredential$nonrefs;
typedef struct _jc_javax_security_auth_x500_X500PrivateCredential$object	_jc_javax_security_auth_x500_X500PrivateCredential$object;

typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vmethods	_jc_javax_security_auth_x500_X500PrivateCredential$vmethods;
typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vtable	_jc_javax_security_auth_x500_X500PrivateCredential$vtable;
typedef const struct _jc_javax_security_auth_x500_X500PrivateCredential$vtype	_jc_javax_security_auth_x500_X500PrivateCredential$vtype;

// Constructors
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$_init$3f4e0e94281bd3b5(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$_init$8ff1e9a1af422b73(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_security_auth_x500_X500PrivateCredential$method$destroy$883b1ab213ac7851(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getAlias$b9393ba4dce5808c(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_X509Certificate$object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getCertificate$8ff48fa1edd22360(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_auth_x500_X500PrivateCredential$method$getPrivateKey$e03d9b3f371a9d56(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_security_auth_x500_X500PrivateCredential$method$isDestroyed$78592fea7eb2b64b(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$destroy$883b1ab213ac7851;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getAlias$b9393ba4dce5808c;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getCertificate$8ff48fa1edd22360;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$getPrivateKey$e03d9b3f371a9d56;
extern _jc_method _jc_javax_security_auth_x500_X500PrivateCredential$method_info$isDestroyed$78592fea7eb2b64b;

// Virtual methods structure
struct _jc_javax_security_auth_x500_X500PrivateCredential$vmethods {
	void	(*destroy$883b1ab213ac7851)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAlias$b9393ba4dce5808c)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_cert_X509Certificate$object	*(*getCertificate$8ff48fa1edd22360)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPrivateKey$e03d9b3f371a9d56)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
	jboolean	(*isDestroyed$78592fea7eb2b64b)(_jc_env *, struct _jc_javax_security_auth_x500_X500PrivateCredential$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_x500_X500PrivateCredential$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_x500_X500PrivateCredential$vmethods	javax_security_auth_x500_X500PrivateCredential;
};

// Vtype
struct _jc_javax_security_auth_x500_X500PrivateCredential$vtype {
	_jc_type			type;
	_jc_javax_security_auth_x500_X500PrivateCredential$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs {
	struct _jc_object	*key;
	struct _jc_java_security_cert_X509Certificate$object	*certificate;
	struct _jc_java_lang_String$object	*alias;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_x500_X500PrivateCredential$refs {
    _jc_javax_security_auth_x500_X500PrivateCredential$sub_refs	javax_security_auth_x500_X500PrivateCredential;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_x500_X500PrivateCredential$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_x500_X500PrivateCredential$sub_nonrefs	javax_security_auth_x500_X500PrivateCredential;
};

// Object instance structure
struct _jc_javax_security_auth_x500_X500PrivateCredential$object {
	_jc_javax_security_auth_x500_X500PrivateCredential$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_x500_X500PrivateCredential$vtype	*vtype;
	_jc_javax_security_auth_x500_X500PrivateCredential$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_x500_X500PrivateCredential$vtype _jc_javax_security_auth_x500_X500PrivateCredential$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_x500_X500PrivateCredential, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_x500_X500PrivateCredential$class_object;

#endif	/* _JC_javax_security_auth_x500_X500PrivateCredential_H_ */
